==> ptcaffe-1.0.0rc1.tar.gz: ptcaffe-1.0.0rc1/ptcaffe/layers/__init__.py <==
# --------------------------------------------------------
# ptcaffe
# Licensed under The MIT License [see LICENSE for details]
# Written by xiaohang
# --------------------------------------------------------

from .caffe_data import CaffeData, CaffeData_MT

from .data_layers import BaseData, RandomData, ImageData, ImageNetData, InputData, ImageCroppingData, MnistData, \
    TorchVisionData, PickleData, SavePickleData

from .container_layers import TorchVisionModel, CaffeNetLayer, TeacherLayer

from .convolution_layers import Convolution, Convolution3D, Deconvolution, SConvolution

from .linear_layers import InnerProduct, SInnerProduct

from .pooling_layers import Pooling, Pooling3D

from .activation_layers import ReLU, ReLU6, Sigmoid, Softmax

from .normalization_layers import BatchNorm, Normalize, LRN, SyncBatchNorm

from .dropout_layers import Dropout, Dropout3D, DropBlock2D

from .recurrent_layers import GRU, LSTM

from .utility_layers import Upsample, Eltwise, Scale, Concat, Reshape, Squeeze, Unsqueeze, ShuffleChannel, Padding

from .ssd_layers import Crop, Slice, Permute, Flatten, PriorBox

from .evaluation_layers import BaseEvaluator, AccuracyEvaluator, Accuracy

from .auxiliary_layers import PrintValue, PrintMean, PrintShape, PrintMinMax, PrintGrad, PrintWeight, PrintWeightGrad, \
    PrintBias, PrintBiasGrad, PrintWeightUpdate, PrintBiasUpdate, PrintMsg, Silence, Identity

from .quantization_layers import QConvolution, QInnerProduct, QPooling, QReLU

from .comm_layers import BroadcastLayer, GatherLayer, AllGatherLayer, ScatterLayer, ReduceAddLayer, AllReduceAddLayer

from .loss_layers import SoftmaxWithLoss, CtcLoss, MimicLoss

==> ptcaffe-1.1.tar.gz: ptcaffe-1.1/ptcaffe/layers/__init__.py <==
# --------------------------------------------------------
# ptcaffe
# Licensed under The MIT License [see LICENSE for details]
# Written by xiaohang
# --------------------------------------------------------

from .caffe_data import CaffeData, CaffeData_MT

from .data_layers import BaseData, ListData, FolderData, RandomData, ImageData, CaffeLmdbData, ImageNetData, InputData, ImageCroppingData, MnistData, \
    TorchVisionData, PickleData, SavePickleData, Hdf5BaseData

from .container_layers import TorchVisionModel, CaffeNetLayer, TeacherLayer

from .convolution_layers import Convolution, Convolution3D, Deconvolution, SConvolution

from .linear_layers import InnerProduct, SInnerProduct

from .pooling_layers import Pooling, Pooling3D

from .activation_layers import ReLU, ReLU6, Sigmoid, Softmax

from .normalization_layers import BatchNorm, Normalize, LRN, SyncBatchNorm

from .dropout_layers import Dropout, Dropout3D, DropBlock2D

from .recurrent_layers import GRU, LSTM

from .utility_layers import Upsample, Eltwise, Scale, Concat, Reshape, Squeeze, Unsqueeze, ShuffleChannel, Padding, SwapChannels

from .ssd_layers import Crop, Slice, Permute, Flatten, PriorBox

from .evaluation_layers import BaseEvaluator, AccuracyEvaluator, Accuracy

from .auxiliary_layers import PrintValue, PrintMean, PrintShape, PrintMinMax, PrintGrad, PrintWeight, PrintWeightGrad, \
    PrintBias, PrintBiasGrad, PrintWeightUpdate, PrintBiasUpdate, PrintMsg, Silence, Identity, CloneOutput, MaxProb

from .quantization_layers import QConvolution, QInnerProduct, QPooling, QReLU

from .comm_layers import BroadcastLayer, GatherLayer, AllGatherLayer, ScatterLayer, ReduceAddLayer, AllReduceAddLayer

from .loss_layers import SoftmaxWithLoss, CtcLoss, MimicLoss, EuclideanLoss

from .pytorch_layers import AdaptiveAvgPool2d, Embedding, EmbeddingBag
